.. VeloxML documentation master file, created by
   sphinx-quickstart on Thu Feb 20 13:10:49 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

VeloxML documentation
=====================

.. include:: ../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   ./veloxml/modules

